@@ -66,6 +66,7 @@ from aldryn_newsblog.models import Article
 from Zephyrus.landing import ErrorCode
 from Zephyrus.landing.models import Email
 from Zephyrus.blog_extension.models import CallToActionModel, CallToActionStatistics
+from Zephyrus.blog_extension import settings as _settings
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
@@ -73,6 +74,13 @@ logger.addHandler(logging.StreamHandler())
 
 PDF_ROOT = 'pdf/'
 
+
+def renderArticle(request, articleId):
+    article = get_object_or_404(Article, pk=hashid_to_int(articleId))
+    domain = Site.objects.get_current().domain
+    context = {'article': article, 'filename': f'{domain}-{article.slug}'}
+    return render(request, _settings.CALL_TO_ACTION_PDF_BASE_TEMPLATE , context)
+
 class CallToActionEmailView(View):
     def post(self, request, *args, **kwargs):
         email = request.POST.get('email')
@@ -179,11 +187,11 @@ def sendAndRedirect(request, email, fromUrl, redirectTo, actionId, formId=None,
 
             if not form:
                 title = (
-                    '[Landing %s] - customer use landing page' %
+                    '[Call To Action %s] - customer use Call To Action Plugin' %
                     request.META['HTTP_HOST'])
             else:
                 title = (
-                    '[Landing %s] - %s' % (
+                    '[Call To Action %s] - %s' % (
                     request.META['HTTP_HOST'], landingForm.name))
 
             if not form:
@@ -217,7 +225,7 @@ def sendAndRedirect(request, email, fromUrl, redirectTo, actionId, formId=None,
             replaceStr.update(fileData)
 
             if not form:
-                title = get_template('blog_extension/call_to_action/ThankEmailSubject.txt')
+                title = _settings.CALL_TO_ACTION_EMAIL_SUBJECT
 
             else:
                 title = landingForm.email_subject
@@ -318,64 +326,20 @@ def showTargetFile(request):
             article = Article.objects.filter(translations__slug=slug)
             if article:
                 article = article[0]
-                
-                # relatedPlugins = a.content.get_plugins()
-                plugin = CMSPlugin.objects.filter(plugin_type='TextPlugin', placeholder=article.content, depth=1)
-                if plugin:
-                    plugin = plugin[0]
-                    
-                    text = Text.objects.get(cmsplugin_ptr_id=plugin.id)
-                    html = text.body
+                articleId = int_to_hashid(article.pk)
+                fileName = f'[{domain}]{article.slug}.pdf'
+                path = settings.MEDIA_URL[1:] + PDF_ROOT + fileName
+                try:
+                    pdfkit.from_url(settings.META_SITE_PROTOCOL + '://' + domain + reverse('renderArticle', kwargs={'articleId': articleId}), path)
 
-                    def transferPicturePlugin(html):
-                        index = 0
-                        while index < len(html):
-                            try:
-                                openIndex = html[index:].index('<cms-plugin') + index
-                            except ValueError:
-                                break
-                            else:
-                                closeIndex = html[openIndex:].index('</cms-plugin>')
-                                pluginHtml = html[openIndex:openIndex+closeIndex]
-                                pluginIdIndex = pluginHtml.index('id') + len('id="')
-                                pluginIdEnd = pluginHtml[pluginIdIndex:].index('"')
-                                pluginId = pluginHtml[pluginIdIndex:pluginIdIndex+pluginIdEnd]
+                # might occur as the https is at risk
+                # the file(img or any file on site) is loaded successfully
+                # with network status code 2 and http status code 0 - Connection closed
+                # Warning: SSL error ignored
+                # Done but Exit with code 1 due to network error: RemoteHostClosedError
+                except Exception as e:
+                    pass
 
-                                index = openIndex + closeIndex + len('</cms-plugin>')
-
-                                plugin = CMSPlugin.objects.get(id=pluginId)
-
-                                if plugin.plugin_type == 'PicturePlugin':
-                                    
-                                    picture = Picture.objects.get(cmsplugin_ptr_id=pluginId)
-
-                                    src = settings.META_SITE_PROTOCOL + '://' + domain + picture.img_src
-                               
-                                    # p.get_size()
-                                    imgtag = f'</p><img src="{src}"></img>'
-
-                                    html = html.replace(html[openIndex:index], imgtag)
-                                    index = openIndex + len(imgtag)
-
-                        return html
-
-                    htmlString = transferPicturePlugin(html)
-                    fileName = f'[{domain}]{article.slug}.pdf'
-                    path = settings.MEDIA_URL[1:] + PDF_ROOT + fileName
-                    try:
-                        pdfkit.from_string('<head><meta charset="UTF-8"></head>' + htmlString, path)
-
-                    # might occur as the https is at risk
-                    # the file(img or any file on site) is loaded successfully
-                    # with network status code 2 and http status code 0 - Connection closed
-                    # Warning: SSL error ignored
-                    # Done but Exit with code 1 due to network error: RemoteHostClosedError
-                    except Exception:
-                        pass
-
-                # no text plugin in blog article
-                else:
-                    return redirect(callToActionStatistics.url)
 
             else:
             
